run_lmer: A wrapper for deciding either to run a default lm or a...

Description Usage Arguments Details Value

View source: R/run_lmer.R

Description

formula: Expr ~ SCORE + Cov + (1|Rcov), where Cov = fixed covariates and Rcov = random covariates

Usage

1
run_lmer(expr, cov, rcov, SCORE, omit.outlier = T, outlier_sd = 3)

Arguments

expr

Expression vector (numeric) with length = #samples (numeric vector)

cov

Regression covariates (fixed effects) in form cov x samples (data frame)

rcov

Regression covariates (random effects) in the form rcov x samples (data frame)

SCORE

mtDNA-CN, not included in cov (numeric vector)

omit.outlier

(no longer supported) Whether or not you want to omit gene expression outliers

Details

Runs linear regression to estimate effect of SCORE on gene expression/metabolite/epigenetic data

Value

A 1 x 6 vector output from an lm() like below: 'intercept', 'beta', 'SE', 't_value', 'pval', 'corr.rho'

Author: Stephanie Yang Adapted from: Vamsee Pillalamarri


syyang93/lmeR documentation built on July 16, 2020, 12:49 a.m.